pub enum YamlNode {
Scalar(YamlScalar),
Sequence(YamlSequence),
Mapping(YamlMapping),
}Expand description
A YAML node accepted by the closed schema-document grammar.
Variants
Scalar(YamlScalar)
Scalar node.
Sequence(YamlSequence)
Sequence node.
Mapping(YamlMapping)
Mapping node.
Implementations
Sourceimpl YamlNode
impl YamlNode
Sourcepub const fn span(&self) -> &SourceSpan
pub const fn span(&self) -> &SourceSpan
Returns the node source span.
Sourcepub const fn as_mapping(&self) -> Option<&YamlMapping>
pub const fn as_mapping(&self) -> Option<&YamlMapping>
Returns this node as a mapping, if it is one.
Sourcepub const fn as_sequence(&self) -> Option<&YamlSequence>
pub const fn as_sequence(&self) -> Option<&YamlSequence>
Returns this node as a sequence, if it is one.
Sourcepub const fn as_scalar(&self) -> Option<&YamlScalar>
pub const fn as_scalar(&self) -> Option<&YamlScalar>
Returns this node as a scalar, if it is one.