pub fn managed_schema_state(
declared: &DeclaredSchema,
context: &ManagedDeltaContext,
) -> Result<ManagedSchemaState, DeltaError>Expand description
Derive the exact managed state from declaration facts and explicit context.
pub fn managed_schema_state(
declared: &DeclaredSchema,
context: &ManagedDeltaContext,
) -> Result<ManagedSchemaState, DeltaError>Derive the exact managed state from declaration facts and explicit context.