pub struct ResolutionOrigin { /* private fields */ }Expand description
Direct-fact identity plus the inheritance path used to derive an effective entry.
Implementations
Sourceimpl ResolutionOrigin
impl ResolutionOrigin
Sourcepub const fn declared(&self) -> &SchemaFactId
pub const fn declared(&self) -> &SchemaFactId
Return the direct fact from which this entry was derived.
Sourcepub fn inheritance_path(&self) -> &[TypeId]
pub fn inheritance_path(&self) -> &[TypeId]
Return the ordered inheritance path; empty means direct.