pub struct SchemaAuthorityError { /* private fields */ }Expand description
A fail-closed schema-authority failure retaining nested diagnostics.
Implementations
Sourceimpl SchemaAuthorityError
impl SchemaAuthorityError
Sourcepub const fn code(&self) -> SchemaAuthorityErrorCode
pub const fn code(&self) -> SchemaAuthorityErrorCode
Return the stable high-level failure classification.
Sourcepub fn contract(&self) -> Option<&Diagnostic>
pub fn contract(&self) -> Option<&Diagnostic>
Return the nested contract diagnostic, when one caused the failure.
Sourcepub fn schema(&self) -> Option<&SchemaDiagnostics>
pub fn schema(&self) -> Option<&SchemaDiagnostics>
Return nested schema diagnostics, when reconstruction or resolution failed.