pub struct SchemaPatternDiscoverySnapshot { /* private fields */ }Expand description
An immutable set of captured schema source bytes parsed after revalidation.
Implementations
Sourceimpl SchemaPatternDiscoverySnapshot
impl SchemaPatternDiscoverySnapshot
Sourcepub const fn documents(&self) -> &SchemaDocumentSet
pub const fn documents(&self) -> &SchemaDocumentSet
Returns the captured, fingerprinted document set.
Sourcepub fn into_documents(self) -> SchemaDocumentSet
pub fn into_documents(self) -> SchemaDocumentSet
Consumes the snapshot and returns its captured document set.