pub struct VerifiedSchemaAuthority { /* private fields */ }Expand description
Opaque source-free authority accepted only after complete reconstruction.
Implementations
Sourceimpl VerifiedSchemaAuthority
impl VerifiedSchemaAuthority
Return the exact fingerprint of the authority content envelope.
Sourcepub const fn declared_schema(&self) -> &DeclaredSchema
pub const fn declared_schema(&self) -> &DeclaredSchema
Return the constructor-validated direct declaration.
Sourcepub const fn resolved_schema(&self) -> &ResolvedSchema
pub const fn resolved_schema(&self) -> &ResolvedSchema
Return independently reconstructed effective schema semantics.
Sourcepub const fn semantic_profile(&self) -> &SemanticProfileBinding
pub const fn semantic_profile(&self) -> &SemanticProfileBinding
Return the registry-resolved semantic-profile identity and content binding.
Sourcepub const fn managed_scope(&self) -> &ManagedScopeBinding
pub const fn managed_scope(&self) -> &ManagedScopeBinding
Return the registry-resolved durable managed-scope binding.
Sourcepub const fn managed_state(&self) -> &ManagedSchemaState
pub const fn managed_state(&self) -> &ManagedSchemaState
Return the independently reconstructed managed schema state.
Sourcepub const fn required_capabilities(&self) -> &CapabilitySet
pub const fn required_capabilities(&self) -> &CapabilitySet
Return the exact additive capability requirements bound by this artifact.