SafetyCondition

Enum SafetyCondition 

pub enum SafetyCondition {
    NoInstances {
        type_id: TypeId,
        include_subtypes: bool,
    },
    OwnsMinimum {
        owns: OwnsFactId,
        minimum: u64,
    },
    OwnsMaximum {
        owns: OwnsFactId,
        maximum: u64,
    },
    RangeLower {
        subject: ScalarSafetySubject,
        lower: CanonicalValue,
    },
    RangeUpper {
        subject: ScalarSafetySubject,
        upper: CanonicalValue,
    },
    ValuesNarrowed {
        subject: ScalarSafetySubject,
        allowed: Vec<CanonicalValue>,
    },
    NoOrphanAttributes {
        attribute: AttributeId,
    },
    Unresolvable {
        reason: UnresolvableSafetyReason,
        unlock: SafetyConditionUnlock,
    },
}
Closed verifier-derived safety-condition vocabulary.

Variants



NoInstances

No instance of a type may exist.

Fields

type_id: TypeId

Type whose instances would violate the transition.

include_subtypes: bool

Whether instances of subtypes also violate the transition.



OwnsMinimum

Every owner must have at least the target number of attributes.

Fields

owns: OwnsFactId

Exact effective ownership being tightened.

minimum: u64

Target minimum. Revision one can lower only the value one.



OwnsMaximum

No owner may have more than the target number of distinct attribute values.

Fields

owns: OwnsFactId

Exact effective ownership being tightened.

maximum: u64

Finite target maximum.



RangeLower

Existing values must not be below a target lower bound.

Fields

subject: ScalarSafetySubject

Exact scalar subject being constrained.

lower: CanonicalValue

Inclusive target lower bound.



RangeUpper

Existing values must not be above a target upper bound.

Fields

subject: ScalarSafetySubject

Exact scalar subject being constrained.

upper: CanonicalValue

Inclusive target upper bound.



ValuesNarrowed

Existing values must belong to the target allowed-value set.

Fields

subject: ScalarSafetySubject

Exact scalar subject being constrained.

allowed: Vec<CanonicalValue>

Canonically ordered, non-empty target allowed values.



NoOrphanAttributes

No attribute instance may be orphaned when @independent is removed.

Fields

attribute: AttributeId

Attribute type losing independent existence.



Unresolvable

The verifier identified a requirement that cannot be silently weakened.

Fields

reason: UnresolvableSafetyReason

Stable explanation of the missing representation.

unlock: SafetyConditionUnlock

Feature or workflow which can unlock the transition.

Implementations

Source

impl SafetyCondition

pub const fn is_resolvable(&self) -> bool

Return whether the current assertion algebra can lower this condition.

pub const fn unlock(&self) -> Option<SafetyConditionUnlock>

Return an explicit missing feature or workflow, when gated.