pub struct FactDependencyGraph { /* private fields */ }Expand description
The exact fact-level dependency graph used to order schema operations.
Implementations
Sourceimpl FactDependencyGraph
impl FactDependencyGraph
Sourcepub fn from_declared(declared: &DeclaredSchema) -> Result<Self, Diagnostic>
pub fn from_declared(declared: &DeclaredSchema) -> Result<Self, Diagnostic>
Build the graph from a complete declared fact inventory.
Sourcepub fn from_facts<'a>(
facts: impl IntoIterator<Item = &'a SchemaFact>,
) -> Result<Self, Diagnostic>
pub fn from_facts<'a>( facts: impl IntoIterator<Item = &'a SchemaFact>, ) -> Result<Self, Diagnostic>
Build the graph from a complete fact inventory.
Sourcepub fn dependencies(&self, id: &SchemaFactId) -> Option<&BTreeSet<SchemaFactId>>
pub fn dependencies(&self, id: &SchemaFactId) -> Option<&BTreeSet<SchemaFactId>>
Return the direct prerequisites of one fact.
Sourcepub fn dependents(&self, id: &SchemaFactId) -> Option<&BTreeSet<SchemaFactId>>
pub fn dependents(&self, id: &SchemaFactId) -> Option<&BTreeSet<SchemaFactId>>
Return the direct dependents of one fact.
Sourcepub fn validate_complete(&self) -> Result<(), Diagnostic>
pub fn validate_complete(&self) -> Result<(), Diagnostic>
Reject an inventory with a dependency outside the inventory.